==> pdfjs-dist-4.0.189.jar: META-INF/resources/webjars/pdfjs-dist/4.0.189/types/src/display/font_loader.d.ts <==
export class FontFaceObject {
    constructor(translatedData: any, { isEvalSupported, disableFontFace, ignoreErrors, inspectFont, }: {
        isEvalSupported?: boolean | undefined;
        disableFontFace?: boolean | undefined;
        ignoreErrors?: boolean | undefined;
        inspectFont?: null | undefined;
    });
    compiledGlyphs: any;
    isEvalSupported: boolean;
    disableFontFace: boolean;
    ignoreErrors: boolean;
    _inspectFont: any;
    createNativeFontFace(): FontFace | null;
    createFontFaceRule(): string | null;
    getPathGenerator(objs: any, character: any): any;
}
export class FontLoader {
    constructor({ ownerDocument, styleElement, }: {
        ownerDocument?: Document | undefined;
        styleElement?: null | undefined;
    });
    _document: Document;
    nativeFontFaces: Set<any>;
    styleElement: HTMLStyleElement | null;
    loadingRequests: any[] | undefined;
    loadTestFontId: number | undefined;
    addNativeFontFace(nativeFontFace: any): void;
    removeNativeFontFace(nativeFontFace: any): void;
    insertRule(rule: any): void;
    clear(): void;
    loadSystemFont({ systemFontInfo: info, _inspectFont }: {
        systemFontInfo: any;
        _inspectFont: any;
    }): Promise<void>;
    bind(font: any): Promise<void>;
    get isFontLoadingAPISupported(): any;
    get isSyncFontLoadingSupported(): any;
    _queueLoadingCallback(callback: any): {
        done: boolean;
        complete: () => void;
        callback: any;
    };
    get _loadTestFont(): any;
    _prepareFontLoadEvent(font: any, request: any): void;
    #private;
}

==> pdfjs-dist-4.2.67.jar: META-INF/resources/webjars/pdfjs-dist/4.2.67/types/src/display/font_loader.d.ts <==
export class FontFaceObject {
    constructor(translatedData: any, { disableFontFace, ignoreErrors, inspectFont }: {
        disableFontFace?: boolean | undefined;
        ignoreErrors?: boolean | undefined;
        inspectFont?: null | undefined;
    });
    compiledGlyphs: any;
    disableFontFace: boolean;
    ignoreErrors: boolean;
    _inspectFont: any;
    createNativeFontFace(): FontFace | null;
    createFontFaceRule(): string | null;
    getPathGenerator(objs: any, character: any): any;
}
export class FontLoader {
    constructor({ ownerDocument, styleElement, }: {
        ownerDocument?: Document | undefined;
        styleElement?: null | undefined;
    });
    _document: Document;
    nativeFontFaces: Set<any>;
    styleElement: HTMLStyleElement | null;
    loadingRequests: any[] | undefined;
    loadTestFontId: number | undefined;
    addNativeFontFace(nativeFontFace: any): void;
    removeNativeFontFace(nativeFontFace: any): void;
    insertRule(rule: any): void;
    clear(): void;
    loadSystemFont({ systemFontInfo: info, _inspectFont }: {
        systemFontInfo: any;
        _inspectFont: any;
    }): Promise<void>;
    bind(font: any): Promise<void>;
    get isFontLoadingAPISupported(): any;
    get isSyncFontLoadingSupported(): any;
    _queueLoadingCallback(callback: any): {
        done: boolean;
        complete: () => void;
        callback: any;
    };
    get _loadTestFont(): any;
    _prepareFontLoadEvent(font: any, request: any): void;
    #private;
}
